==> polarion_rest_api_client-1.2.1.tar.gz: polarion_rest_api_client-1.2.1/polarion_rest_api_client/open_api_client/models/testruns_single_patch_request_data_relationships_document.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.testruns_single_patch_request_data_relationships_document_data import (
        TestrunsSinglePatchRequestDataRelationshipsDocumentData,
    )


T = TypeVar("T", bound="TestrunsSinglePatchRequestDataRelationshipsDocument")


@_attrs_define
class TestrunsSinglePatchRequestDataRelationshipsDocument:
    """
    Attributes:
        data (Union[Unset, TestrunsSinglePatchRequestDataRelationshipsDocumentData]):
    """

    data: Union[
        Unset, "TestrunsSinglePatchRequestDataRelationshipsDocumentData"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        data: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.testruns_single_patch_request_data_relationships_document_data import (
            TestrunsSinglePatchRequestDataRelationshipsDocumentData,
        )

        d = src_dict.copy()
        _data = d.pop("data", UNSET)
        data: Union[
            Unset, TestrunsSinglePatchRequestDataRelationshipsDocumentData
        ]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = TestrunsSinglePatchRequestDataRelationshipsDocumentData.from_dict(
                _data
            )

        testruns_single_patch_request_data_relationships_document_obj = cls(
            data=data,
        )

        testruns_single_patch_request_data_relationships_document_obj.additional_properties = (
            d
        )
        return testruns_single_patch_request_data_relationships_document_obj

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.4.tar.gz: polarion_rest_api_client-1.4.4/polarion_rest_api_client/open_api_client/models/testruns_single_patch_request_data_relationships_document.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import (
    TYPE_CHECKING,
    Any,
    TypeVar,
    Union,
)

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.testruns_single_patch_request_data_relationships_document_data import (
        TestrunsSinglePatchRequestDataRelationshipsDocumentData,
    )


T = TypeVar("T", bound="TestrunsSinglePatchRequestDataRelationshipsDocument")


@_attrs_define
class TestrunsSinglePatchRequestDataRelationshipsDocument:
    """
    Attributes:
        data (Union[Unset, TestrunsSinglePatchRequestDataRelationshipsDocumentData]):
    """

    data: Union[
        Unset, "TestrunsSinglePatchRequestDataRelationshipsDocumentData"
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        data: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.testruns_single_patch_request_data_relationships_document_data import (
            TestrunsSinglePatchRequestDataRelationshipsDocumentData,
        )

        d = dict(src_dict)
        _data = d.pop("data", UNSET)
        data: Union[
            Unset, TestrunsSinglePatchRequestDataRelationshipsDocumentData
        ]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = TestrunsSinglePatchRequestDataRelationshipsDocumentData.from_dict(
                _data
            )

        testruns_single_patch_request_data_relationships_document_obj = cls(
            data=data,
        )

        testruns_single_patch_request_data_relationships_document_obj.additional_properties = d
        return testruns_single_patch_request_data_relationships_document_obj

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
